@@ -6,13 +6,14 @@ use utf8;
 use warnings;
 
 # Version.
-our $VERSION = 0.19;
+our $VERSION = 0.20;
 
 # Modules.
 use Acme::CPANAuthors::Register(
 	'CHOROBA' => 'E. Choroba',
 	'DANIELR' => 'Roman Daniel',
 	'DANPEDER' => 'Daniel Peder',
+	'DOUGLISH' => 'Dalibor Hořínek',
 	'HIHIK' => 'Jiří Václavík',
 	'HPA' => 'Petr Vraník',
 	'JANPAZ' => 'Jan Pazdziora',
@@ -93,7 +94,7 @@ See documentation for L<Acme::CPANAuthors> for more details.
  print "Count of Czech CPAN authors: $count\n";
 
  # Output:
- # Count of Czech CPAN authors: 35
+ # Count of Czech CPAN authors: 36
 
 =head1 EXAMPLE2
 
@@ -119,38 +120,39 @@ See documentation for L<Acme::CPANAuthors> for more details.
  #     [0]  "CHOROBA",
  #     [1]  "DANIELR",
  #     [2]  "DANPEDER",
- #     [3]  "HIHIK",
- #     [4]  "HPA",
- #     [5]  "JANPAZ",
- #     [6]  "JANPOM",
- #     [7]  "JENDA",
- #     [8]  "JIRA",
- #     [9]  "JSPICAK",
- #     [10] "KLE",
- #     [11] "KOLCON",
- #     [12] "MAJLIS",
- #     [13] "MICHALS",
- #     [14] "MILSO",
- #     [15] "MJFO",
- #     [16] "PAJAS",
- #     [17] "PASKY",
- #     [18] "PEK",
- #     [19] "POPEL",
- #     [20] "PSME",
- #     [21] "RUR",
- #     [22] "RVASICEK",
- #     [23] "SEIDLJAN",
- #     [24] "SKIM",
- #     [25] "SMRZ",
- #     [26] "STRAKA",
- #     [27] "TKR",
- #     [28] "TRIPIE",
- #     [29] "TYNOVSKY",
- #     [30] "VASEKD",
- #     [31] "YENYA",
- #     [32] "ZABA",
- #     [33] "ZEMAN",
- #     [34] "ZOUL"
+ #     [3]  "DOUGLISH",
+ #     [4]  "HIHIK",
+ #     [5]  "HPA",
+ #     [6]  "JANPAZ",
+ #     [7]  "JANPOM",
+ #     [8]  "JENDA",
+ #     [9]  "JIRA",
+ #     [10] "JSPICAK",
+ #     [11] "KLE",
+ #     [12] "KOLCON",
+ #     [13] "MAJLIS",
+ #     [14] "MICHALS",
+ #     [15] "MILSO",
+ #     [16] "MJFO",
+ #     [17] "PAJAS",
+ #     [18] "PASKY",
+ #     [19] "PEK",
+ #     [20] "POPEL",
+ #     [21] "PSME",
+ #     [22] "RUR",
+ #     [23] "RVASICEK",
+ #     [24] "SEIDLJAN",
+ #     [25] "SKIM",
+ #     [26] "SMRZ",
+ #     [27] "STRAKA",
+ #     [28] "TKR",
+ #     [29] "TRIPIE",
+ #     [30] "TYNOVSKY",
+ #     [31] "VASEKD",
+ #     [32] "YENYA",
+ #     [33] "ZABA",
+ #     [34] "ZEMAN",
+ #     [35] "ZOUL"
  # ]
 
 =head1 DEPENDENCIES
@@ -174,6 +176,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.19
+0.20
 
 =cut
